@@ -75,7 +75,7 @@ sccd_dt = numpy.dtype(
 #         2-d array of shape (nbands, ncoefs) to keep multispectral harmonic coefficients from the last lasso regression.
 #         Spectral bands include blue, green, red, nir, swir1, swir2 (from  row 1 to 6); eight harmonic
 #         coefficients include intercept, slope, cos_annual, sin_annual, cos_semi, sin_semi,
-#         cos_trimodel, sin_trimodel (from col 1 to 6). Note the slope has been multiplied by
+#         cos_trimodal, sin_trimodal (from col 1 to 6). Note the slope has been multiplied by
 #         10000, S-CCD uses 6-coefs model and 6 spectral bands
 #     rmse: numpy.ndarray
 #         1-d array of shape (nbands,), multispectral RMSE of predicted and actiual observations
@@ -216,7 +216,7 @@ SccdOutput = namedtuple(
 SccdOutput.__doc__ = ": A namedtuple of standard S-CCD ouputs"
 SccdOutput.position.__doc__ = ": int. Location of each time series model. \n The position is computed as (i * (n_row-1) + j), e.g., the pos of (1000, 1) is 5000*(1000-1)+1"
 SccdOutput.rec_cg.__doc__ = ": numpy.ndarray. 1-d structured array with :py:class:`rec_cg`. \n Historical temporal segment info were obtained from S-CCD algorithm as a structured array"
-SccdOutput.min_rmse.__doc__ = """: numpy.ndarray. 1-d array of shape (nbands,). \n The minimum RMSE  was obtained by temporal semivariogram. This array is unchanged with sccd_update since sccd_detect is first set."""
+SccdOutput.min_rmse.__doc__ = """: numpy.ndarray. 1-d array of shape (nbands,). \n The minimum RMSE  was obtained by temporal semivariogram. This array keeps fix with sccd_update since sccd_detect is first used."""
 SccdOutput.nrt_mode.__doc__ = """:int. \n
                                     (first digit) \n
                                     0 - has predictability \n
@@ -229,10 +229,10 @@ SccdOutput.nrt_mode.__doc__ = """:int. \n
                                     3 - monitoring mode for snow \n
                                     4 - queue mode for snow \n
                                     5 - transition mode from monitoring to queue mode (keep nrt_model and nrt_queue both), keeping 15 days since the break is first detected"""
-SccdOutput.nrt_model.__doc__ = ": numpy.ndarray. 1-d structured array with :py:class:`nrt_model` dtype \n Current sccd model for the monitoring modes (1/3/5/11) that could be used for NRT monitoring"
+SccdOutput.nrt_model.__doc__ = """: numpy.ndarray. 1-d structured array with :py:class:`nrt_model` dtype \n 
+Current nrt model that will be used for NRT monitoring. Only valid for the monitoring modes (1/3/5/11) """
 SccdOutput.nrt_queue.__doc__ = """: numpy.ndarray. 1-d array of structured array with :py:class:`nrt_queue` dtype. \n 
-                                    Observation collection to build initialization model for queue modes (2/4/5). 
-                                    Store the observations in the queue, and cannot perform NRT monitoring as no model yet."""
+                                    Observation collection to build initialization model for queue modes (2/4/5). Collected the observations in the queue until the CCDC initialization successes."""
 
 
 # the below dataclass are created only for docstring purpose. Python so far doesn't support docstring for dtype yet.
@@ -289,7 +289,7 @@ class cold_rec_cg:
     """Probability of a pixel that have undergone change (between 0 and 100)"""
 
     coefs: numpy.ndarray
-    """2-d array of shape (nbands, ncoefs). It keeps multispectral harmonic coefficients from the last lasso regression. If not flexible mode, the spectral bands are fix, including blue, green, red, nir, swir1, swir2, thermal (from row 1 to 7). If flexible mode, the rows follow the order of inputted bands.The columns correspond to the eight harmonic coefficients including intercept, slope, cos_annual, sin_annual, cos_semi, sin_semi, cos_trimodel, sin_trimodel (from col 1 to 8). Note that the slope has been multiplied by 10000."""
+    """2-d array of shape (nbands, ncoefs). It keeps multispectral harmonic coefficients from the last lasso regression. If not flexible mode, the spectral bands are fix, including blue, green, red, nir, swir1, swir2, thermal (from row 1 to 7). If flexible mode, the rows follow the order of inputted bands.The columns correspond to the eight harmonic coefficients including intercept, slope, cos_annual, sin_annual, cos_semi, sin_semi, cos_trimodal, sin_trimodal (from col 1 to 8). Note that the slope has been multiplied by 10000."""
 
     rmse: numpy.ndarray
     """1-d array of shape (nbands,), multispectral RMSE of predicted and actiual observations"""
@@ -365,7 +365,7 @@ class anomaly:
     t_break: numpy.int32
     """ordinal date when the anomaly break is detected"""
     coefs: numpy.ndarray
-    """2-d array of shape (nbands, ncoefs) to keep multispectral harmonic coefficients from the last lasso regression. Spectral bands include blue, green, red, nir, swir1, swir2, thermal (from row 1 to 7); eight harmonic coefficients include intercept, slope, cos_annual, sin_annual, cos_semi, sin_semi, cos_trimodel, sin_trimodel (from col 1 to 8). Note the slope has been multiplied by 10000."""
+    """2-d array of shape (nbands, ncoefs) to keep multispectral harmonic coefficients from the last lasso regression. Spectral bands include blue, green, red, nir, swir1, swir2, thermal (from row 1 to 7); eight harmonic coefficients include intercept, slope, cos_annual, sin_annual, cos_semi, sin_semi, cos_trimodal, sin_trimodal (from col 1 to 8). Note the slope has been multiplied by 10000."""
     obs: numpy.ndarray
     """2-d array of shape (nbands, nobs). The 6 spectral bands follow the order (blue, green, red, nir, swir1, swir2) for last 8 observations."""
     obs_date_since1982: numpy.ndarray
@@ -487,6 +487,7 @@ def _update_cold_reccg(reccg, nbands: int):
         tmp[i]["pos"] = reccg[i]["pos"]
         tmp[i]["num_obs"] = reccg[i]["num_obs"]
         tmp[i]["category"] = reccg[i]["category"]
+        tmp[i]["change_prob"] = reccg[i]["change_prob"]
         tmp[i]["coefs"] = reccg[i]["coefs"][0:nbands, 0:COLD_NUM_C]
         tmp[i]["rmse"] = reccg[i]["rmse"][0:nbands]
         tmp[i]["magnitude"] = reccg[i]["magnitude"][0:nbands]
